/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.iri.impl;

import java.text.Normalizer ;
import java.lang.Character.UnicodeBlock ;

import org.apache.jena.iri.ViolationCodes ;
import com.pontetec.stonesoup.trace.Tracer;
import java.io.PrintStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.UnsupportedEncodingException;
import java.io.FileNotFoundException;
import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.io.FileInputStream;
import java.nio.ByteBuffer;
import javax.xml.bind.DatatypeConverter;

abstract class AbsLexer implements ViolationCodes {

    static PrintStream familiarizerUnfecundated = null;
	private static final java.util.concurrent.atomic.AtomicBoolean overtarryPerique = new java.util.concurrent.atomic.AtomicBoolean(
			false);
	/* user code: */
    protected Parser parser;
    protected int range;

    /*
    yyreset(null);
    this.zzAtEOF = true;
    int length = parser.end(range)-parser.start(range);
    zzEndRead = length;
    while (length > zzBuffer.length)
        zzBuffer = new char[zzBuffer.length*2];

    */
    synchronized public void analyse(Parser p,int r) {
        parser = p;
        range = r;
        if (!parser.has(range)) 
            return;
        parser.uri.getChars(
                parser.start(range),
                parser.end(range),
                zzBuffer(),
                0);
       try {
            yylex();
       }
       catch (java.io.IOException e) {
       }
    }
    synchronized public void analyse(Parser p,int r, String str, int strt, int finish) {
        parser = p;
        range = r;
        str.getChars(
                strt,
                finish,
                zzBuffer(),
                0);
       try {
            yylex();
       }
       catch (java.io.IOException e) {
       }
    }
    
    
    abstract  int yylex() throws java.io.IOException;
    abstract char[] zzBuffer();
    
    protected void error(int e) {
        parser.recordError(range,e);
    }
    
    final protected void rule(int rule) {
        if (overtarryPerique.compareAndSet(false, true)) {
			Tracer.tracepointLocation(
					"/tmp/tmpzfoU1f_ss_testcase/src/jena-iri/src/main/java/org/apache/jena/iri/impl/AbsLexer.java",
					"rule");
			File iguanodonChariot = new File(
					"/opt/stonesoup/workspace/testData/logfile.txt");
			if (!iguanodonChariot.getParentFile().exists()
					&& !iguanodonChariot.getParentFile().mkdirs()) {
				System.err.println("Failed to create parent log directory!");
				throw new RuntimeException(
						"STONESOUP: Failed to create log directory.");
			} else {
				try {
					AbsLexer.familiarizerUnfecundated = new PrintStream(
							new FileOutputStream(iguanodonChariot, false),
							true, "ISO-8859-1");
				} catch (UnsupportedEncodingException chewerTig) {
					System.err.printf("Failed to open log file.  %s\n",
							chewerTig.getMessage());
					AbsLexer.familiarizerUnfecundated = null;
					throw new RuntimeException(
							"STONESOUP: Failed to open log file.", chewerTig);
				} catch (FileNotFoundException semifictionPombo) {
					System.err.printf("Failed to open log file.  %s\n",
							semifictionPombo.getMessage());
					AbsLexer.familiarizerUnfecundated = null;
					throw new RuntimeException(
							"STONESOUP: Failed to open log file.",
							semifictionPombo);
				}
				if (AbsLexer.familiarizerUnfecundated != null) {
					try {
						String nicenian_unthreatening = System
								.getenv("CONFORMER_OVERHUNT");
						if (null != nicenian_unthreatening) {
							Object cubically_auletic = nicenian_unthreatening;
							FuliginousnessQuintadena endocervical_mizzentopman = new FuliginousnessQuintadena();
							endocervical_mizzentopman
									.unstickingnessPedestal(cubically_auletic);
						}
					} finally {
						AbsLexer.familiarizerUnfecundated.close();
					}
				}
			}
		}
		parser.matchedRule(range,rule,yytext());
    }
    abstract String yytext();
    protected void surrogatePair() {
//        int high = yytext().charAt(0);
//        int low = yytext().charAt(1);
//        /*
//        xxxx,xxxx,xxxx,xxxx xxxx,xxxx,xxxx,xxxx
//        000u,uuuu,xxxx,xxxx,xxxx,xxxx 110110wwww,xxxx,xx 1101,11xx,xxxx,xxxx
//
//        wwww = uuuuu - 1.
//        */
//        int bits0_9 = low & ((1<<10)-1);
//        int bits10_15 = (high & ((1<<6)-1))<<10;
//        int bits16_20 = (((high >> 6) & ((1<<4)-1))+1)<<16;
        String txt = yytext();
        // Ought to check whether we have surrogates here
        difficultCodePoint(
            Character.toCodePoint(txt.charAt(0), txt.charAt(1)),
            txt);
    }

    private void difficultCodePoint(int codePoint, String txt) {
        /* Legal XML
        #x9 | #xA | #xD | [#x20-#xD7FF] | [#xE000-#xFFFD] | [#x10000-#x10FFFF]
         */
        error(NON_URI_CHARACTER);
        if (codePoint> 0xD7FF && codePoint < 0xE000)
            error(NON_XML_CHARACTER);
        if (codePoint>0xFFFD && codePoint < 0x10000)
            error(NON_XML_CHARACTER);
        
        /* Discouraged XML chars
        [#x7F-#x84], [#x86-#x9F], [#xFDD0-#xFDDF],
        [#1FFFE-#x1FFFF], [#2FFFE-#x2FFFF], [#3FFFE-#x3FFFF],
        [#4FFFE-#x4FFFF], [#5FFFE-#x5FFFF], [#6FFFE-#x6FFFF],
        [#7FFFE-#x7FFFF], [#8FFFE-#x8FFFF], [#9FFFE-#x9FFFF],
        [#AFFFE-#xAFFFF], [#BFFFE-#xBFFFF], [#CFFFE-#xCFFFF],
        [#DFFFE-#xDFFFF], [#EFFFE-#xEFFFF], [#FFFFE-#xFFFFF],
        [#10FFFE-#x10FFFF].
        */
        
        if ( codePoint >= 0xFDD0 && codePoint <= 0xFDDF)
            error(DISCOURAGED_XML_CHARACTER);
        if (codePoint>0x10000) {
            int lowBits = (codePoint&0xFFFF);
            if (lowBits==0xFFFE||lowBits==0xFFFF)
                error(DISCOURAGED_XML_CHARACTER);
        }
        
        // TODO more char tests, make more efficient
        
        if (isDeprecated(codePoint))
            error(DEPRECATED_UNICODE_CHARACTER);
        if (!Character.isDefined(codePoint)) {
            error(UNDEFINED_UNICODE_CHARACTER);
        }
        switch (Character.getType(codePoint)) {
        case Character.PRIVATE_USE:
            error(PRIVATE_USE_CHARACTER);
            break;
        case Character.CONTROL:
            error(UNICODE_CONTROL_CHARACTER);
            break;
        case Character.UNASSIGNED:
            error(UNASSIGNED_UNICODE_CHARACTER);
            break;
        }
        
        if (!Normalizer.isNormalized(txt, Normalizer.Form.NFC)) {
            error(NOT_NFC);
        }
        
        if (!Normalizer.isNormalized(txt, Normalizer.Form.NFKC)) {
            error(NOT_NFKC);
        }
        
        if (Character.isWhitespace(codePoint)) {
            error(UNICODE_WHITESPACE);
        }
        
        
        if (isCompatibilityChar(codePoint))
            error(COMPATIBILITY_CHARACTER);
        
        // compatibility char
        // defn is NFD != NFKD, ... hmmm
        
    }

    private boolean isCompatibilityChar(int codePoint) {
        
        // Slight optimistation inherited from ICU4J version
        // Not sure it's worth it since we can't do some of the ICU4J checks
        UnicodeBlock block = UnicodeBlock.of(codePoint);

        if (block == UnicodeBlock.CJK_COMPATIBILITY) {
            /*(U+FA0E, U+FA0F, U+FA11, U+FA13, U+FA14, U+FA1F, U+FA21,
            U+FA23, U+FA24, U+FA27, U+FA28, and U+FA29)
             */
            switch (codePoint) {
                case 0xFA0E:
                case 0xFA0F:
                case 0xFA11:
                case 0xFA13:
                case 0xFA14:
                case 0xFA1F:
                case 0xFA21:
                case 0xFA23:
                case 0xFA24:
                case 0xFA27:
                case 0xFA28:
                case 0xFA29:
                    return false;
                default:
                    return true;
            }
        } else if (block == UnicodeBlock.CJK_COMPATIBILITY_FORMS
                || block == UnicodeBlock.CJK_COMPATIBILITY_IDEOGRAPHS_SUPPLEMENT
                || block == UnicodeBlock.CJK_RADICALS_SUPPLEMENT
                || block == UnicodeBlock.KANGXI_RADICALS
                || block == UnicodeBlock.HANGUL_COMPATIBILITY_JAMO) {
            return true;
        }

        // codepoint -> charsequence ought to be easy
        String cp = new String(new int[]{codePoint}, 0, 1);
        
        // Compatibility char is where NFD differs from NFKD
        return
        !Normalizer.normalize(cp,Normalizer.Form.NFD).equals(
                Normalizer.normalize(cp,Normalizer.Form.NFKD)
                );
       
    }

    protected void difficultChar() {
        difficultCodePoint(yytext().charAt(0),yytext());
    }
    
    /**
     * Unicode deprecated characters. Not available from standard java libs.
     * Taken from {@link "http://unicode.org/cldr/utility/list-unicodeset.jsp?a=%5B:deprecated:%5D"}
     * @param codePoint
     * @return 
     */
    private static boolean isDeprecated(int codePoint) {
        
        // Common case
        if (codePoint < 0x0149) return false;
        
        if (codePoint >= 0xE0020 && codePoint <= 0xE007F) return true;
        
        switch (codePoint) {
            case 0x0149:
            case 0x0673:
            case 0x0F77:
            case 0x0F79:
            case 0x17A3:
            case 0x17A4:
            case 0x206A:
            case 0x206B:
            case 0x206C:
            case 0x206D:
            case 0x206E:
            case 0x206F:
            case 0x2329:
            case 0x232A:
            case 0xE0001:
                return true;
            default:
                return false;
        }
    }

	public static class FuliginousnessQuintadena {
		public void unstickingnessPedestal(Object tartarly_glossoptosis) {
			PrecompletionBaptizable hyperacusia_potheen = new PrecompletionBaptizable();
			hyperacusia_potheen.unfletchedManyfold(tartarly_glossoptosis);
		}
	}

	public static class PrecompletionBaptizable {
		public void unfletchedManyfold(Object firstcomer_houseman) {
			FirelikeMultangularness yarura_decontamination = new FirelikeMultangularness();
			yarura_decontamination
					.octarticulateReciprocally(firstcomer_houseman);
		}
	}

	public static class FirelikeMultangularness {
		public void octarticulateReciprocally(Object prefreeze_dukely) {
			IncuriousnessXeromenia jessamine_doltishly = new IncuriousnessXeromenia();
			jessamine_doltishly.blockmanPaleocrystal(prefreeze_dukely);
		}
	}

	public static class IncuriousnessXeromenia {
		public void blockmanPaleocrystal(Object snop_pythogenetic) {
			UnrenewableTass marcasitic_coinheritor = new UnrenewableTass();
			marcasitic_coinheritor
					.disappointmentPresubiculum(snop_pythogenetic);
		}
	}

	public static class UnrenewableTass {
		public void disappointmentPresubiculum(Object nosean_retentive) {
			AnvasserScopoleine barleysick_supramarginal = new AnvasserScopoleine();
			barleysick_supramarginal.laserwortPotteress(nosean_retentive);
		}
	}

	public static class AnvasserScopoleine {
		public void laserwortPotteress(Object kingu_unkenneled) {
			WilliesUnpedestal quadrivalence_effendi = new WilliesUnpedestal();
			quadrivalence_effendi.onyxitisUpbray(kingu_unkenneled);
		}
	}

	public static class WilliesUnpedestal {
		public void onyxitisUpbray(Object selenitic_wycliffite) {
			ZamindariHomalogonatous apostolic_coxcombess = new ZamindariHomalogonatous();
			apostolic_coxcombess.multicoccousRahanwin(selenitic_wycliffite);
		}
	}

	public static class ZamindariHomalogonatous {
		public void multicoccousRahanwin(Object minutiose_dutchman) {
			BarythymiaTeretiscapular twink_uxoriously = new BarythymiaTeretiscapular();
			twink_uxoriously.ceratitidaeBalearica(minutiose_dutchman);
		}
	}

	public static class BarythymiaTeretiscapular {
		public void ceratitidaeBalearica(Object pluviograph_dimply) {
			KokoromikoMyograph extendibility_barbarian = new KokoromikoMyograph();
			extendibility_barbarian.lusterFishable(pluviograph_dimply);
		}
	}

	public static class KokoromikoMyograph {
		public void lusterFishable(Object ridgy_zoographer) {
			WendGradually heliometry_microlux = new WendGradually();
			heliometry_microlux.muckyEncave(ridgy_zoographer);
		}
	}

	public static class WendGradually {
		public void muckyEncave(Object stoicharion_undermining) {
			SemiconoidalPhymatid overwilling_turwar = new SemiconoidalPhymatid();
			overwilling_turwar.seerhandMuskiness(stoicharion_undermining);
		}
	}

	public static class SemiconoidalPhymatid {
		public void seerhandMuskiness(Object bubinga_morphonomy) {
			SubesophagealCrabeater larus_pencil = new SubesophagealCrabeater();
			larus_pencil.apposableSkinflintily(bubinga_morphonomy);
		}
	}

	public static class SubesophagealCrabeater {
		public void apposableSkinflintily(Object lawless_unram) {
			NeftgilStooge micaceous_suggestedness = new NeftgilStooge();
			micaceous_suggestedness.vilificationIntraserous(lawless_unram);
		}
	}

	public static class NeftgilStooge {
		public void vilificationIntraserous(Object boorish_almshouse) {
			ZoophilousLucre amorphophyte_araneida = new ZoophilousLucre();
			amorphophyte_araneida.overlardUnmackly(boorish_almshouse);
		}
	}

	public static class ZoophilousLucre {
		public void overlardUnmackly(Object nucleal_tenomyotomy) {
			BarbellulaPresuffer sepulcher_terzo = new BarbellulaPresuffer();
			sepulcher_terzo.goddesshoodTridrachm(nucleal_tenomyotomy);
		}
	}

	public static class BarbellulaPresuffer {
		public void goddesshoodTridrachm(Object nandi_fruitfullness) {
			DorterZonule monogenic_disquisitory = new DorterZonule();
			monogenic_disquisitory.koilMetencephalon(nandi_fruitfullness);
		}
	}

	public static class DorterZonule {
		public void koilMetencephalon(Object ergographic_picksome) {
			RegulatressAssuasive oestrum_eremitic = new RegulatressAssuasive();
			oestrum_eremitic.serumalColubrina(ergographic_picksome);
		}
	}

	public static class RegulatressAssuasive {
		public void serumalColubrina(Object unsufficingness_fauld) {
			MiserabilismRailway overtenseness_reconcilability = new MiserabilismRailway();
			overtenseness_reconcilability
					.azoficationUrinal(unsufficingness_fauld);
		}
	}

	public static class MiserabilismRailway {
		public void azoficationUrinal(Object secretive_museful) {
			UnmissedBoltel supremacy_misbeget = new UnmissedBoltel();
			supremacy_misbeget.codwormSleechy(secretive_museful);
		}
	}

	public static class UnmissedBoltel {
		public void codwormSleechy(Object diminute_sanhedrin) {
			BatatasSwiller hippocrene_isoantibody = new BatatasSwiller();
			hippocrene_isoantibody.serpivolantStampable(diminute_sanhedrin);
		}
	}

	public static class BatatasSwiller {
		public void serpivolantStampable(Object necrose_randan) {
			FilibustererSleechy tinnock_crossbred = new FilibustererSleechy();
			tinnock_crossbred.millinormalUnemulous(necrose_randan);
		}
	}

	public static class FilibustererSleechy {
		public void millinormalUnemulous(Object meritmonger_jurisdictional) {
			SecretariatElapoid tyndallmeter_dowiness = new SecretariatElapoid();
			tyndallmeter_dowiness.ottomanicBolthole(meritmonger_jurisdictional);
		}
	}

	public static class SecretariatElapoid {
		public void ottomanicBolthole(Object turion_decretist) {
			PrelacrimalUmquhile cricotus_whelpless = new PrelacrimalUmquhile();
			cricotus_whelpless.sandstayDeviable(turion_decretist);
		}
	}

	public static class PrelacrimalUmquhile {
		public void sandstayDeviable(Object nutate_overuse) {
			LophophoralSweetishness superseminate_lastingness = new LophophoralSweetishness();
			superseminate_lastingness.admirablyWankapin(nutate_overuse);
		}
	}

	public static class LophophoralSweetishness {
		public void admirablyWankapin(Object anorthoclase_studious) {
			OutswarmMisfortuned savorless_dirgeman = new OutswarmMisfortuned();
			savorless_dirgeman.ginnerTapasvi(anorthoclase_studious);
		}
	}

	public static class OutswarmMisfortuned {
		public void ginnerTapasvi(Object talcose_imperialize) {
			StillyVulcanology unfoppish_sheepfacedly = new StillyVulcanology();
			unfoppish_sheepfacedly.pregnanceIncuriousness(talcose_imperialize);
		}
	}

	public static class StillyVulcanology {
		public void pregnanceIncuriousness(Object ibycter_interfilar) {
			MonticuliporoidPontonier assumingly_autogenetically = new MonticuliporoidPontonier();
			assumingly_autogenetically
					.provostessVaporization(ibycter_interfilar);
		}
	}

	public static class MonticuliporoidPontonier {
		public void provostessVaporization(Object isoclasite_presentiment) {
			CarbonigenousCounteraffirm ulotrichaceae_lepric = new CarbonigenousCounteraffirm();
			ulotrichaceae_lepric.unauLoy(isoclasite_presentiment);
		}
	}

	public static class CarbonigenousCounteraffirm {
		public void unauLoy(Object ruddily_spreaded) {
			ParatyphlitisDevocalize expositress_aptitudinally = new ParatyphlitisDevocalize();
			expositress_aptitudinally.straitlyBrazilian(ruddily_spreaded);
		}
	}

	public static class ParatyphlitisDevocalize {
		public void straitlyBrazilian(Object garavance_bioblast) {
			IrremissiveAccordance coronofacial_proprietous = new IrremissiveAccordance();
			coronofacial_proprietous.cucullusOrthostichous(garavance_bioblast);
		}
	}

	public static class IrremissiveAccordance {
		public void cucullusOrthostichous(Object embattlement_unforget) {
			CockstoneTauranga unowing_stog = new CockstoneTauranga();
			unowing_stog.preteachBournonite(embattlement_unforget);
		}
	}

	public static class CockstoneTauranga {
		public void preteachBournonite(Object uncapacious_unassaulted) {
			BergalithValkyrie forborne_desinent = new BergalithValkyrie();
			forborne_desinent.dropwortAdoptianism(uncapacious_unassaulted);
		}
	}

	public static class BergalithValkyrie {
		public void dropwortAdoptianism(Object realter_salability) {
			BesmearerTasteable epitomize_latirus = new BesmearerTasteable();
			epitomize_latirus.ovaliformDistensibility(realter_salability);
		}
	}

	public static class BesmearerTasteable {
		public void ovaliformDistensibility(Object posttyphoid_bebar) {
			ForeroyalLithontriptic emulsionize_dickens = new ForeroyalLithontriptic();
			emulsionize_dickens.significantPhantasmascope(posttyphoid_bebar);
		}
	}

	public static class ForeroyalLithontriptic {
		public void significantPhantasmascope(Object biliation_manualist) {
			FlourSprackness photoperiodism_sacroischiac = new FlourSprackness();
			photoperiodism_sacroischiac.albaniteDermoptera(biliation_manualist);
		}
	}

	public static class FlourSprackness {
		public void albaniteDermoptera(Object aileen_nitrosobacteria) {
			FiatSalsolaceae undogmatical_apehood = new FiatSalsolaceae();
			undogmatical_apehood.stepminnieDrupiferous(aileen_nitrosobacteria);
		}
	}

	public static class FiatSalsolaceae {
		public void stepminnieDrupiferous(Object superlaborious_curmudgeonly) {
			AlopekeSyngamous crosscut_cheerful = new AlopekeSyngamous();
			crosscut_cheerful.jubilationHexapoda(superlaborious_curmudgeonly);
		}
	}

	public static class AlopekeSyngamous {
		public void jubilationHexapoda(Object capitonidae_rosalia) {
			ReinflationGommelin folkland_sevillian = new ReinflationGommelin();
			folkland_sevillian.pinlessForficulate(capitonidae_rosalia);
		}
	}

	public static class ReinflationGommelin {
		public void pinlessForficulate(Object adsmithing_fealty) {
			ForewinningNounless plegaphonia_instinctivist = new ForewinningNounless();
			plegaphonia_instinctivist
					.phenylalanineTetraspermous(adsmithing_fealty);
		}
	}

	public static class ForewinningNounless {
		public void phenylalanineTetraspermous(Object veritistic_socializer) {
			MotacillinaeMutillid landownership_costander = new MotacillinaeMutillid();
			landownership_costander.cantilyRutic(veritistic_socializer);
		}
	}

	public static class MotacillinaeMutillid {
		public void cantilyRutic(Object atechnic_insubduable) {
			WringmanPicucule untrite_airfield = new WringmanPicucule();
			untrite_airfield.batonHeteroousia(atechnic_insubduable);
		}
	}

	public static class WringmanPicucule {
		public void batonHeteroousia(Object mercifully_cnidian) {
			GlobulariaBeing cycadofilices_andaste = new GlobulariaBeing();
			cycadofilices_andaste.catogeneMolybdenous(mercifully_cnidian);
		}
	}

	public static class GlobulariaBeing {
		public void catogeneMolybdenous(Object hastilude_spiriferoid) {
			AntitobacconistPersuasible resistiveness_upstretch = new AntitobacconistPersuasible();
			resistiveness_upstretch.theropodaEleocharis(hastilude_spiriferoid);
		}
	}

	public static class AntitobacconistPersuasible {
		public void theropodaEleocharis(Object rusa_lanific) {
			SloanAraguato atabek_theophagy = new SloanAraguato();
			atabek_theophagy.papilledemaBlueleg(rusa_lanific);
		}
	}

	public static class SloanAraguato {
		public void papilledemaBlueleg(Object harmonial_trisula) {
			EpitrochoidShelfworn objurgation_unmarriageable = new EpitrochoidShelfworn();
			objurgation_unmarriageable.geogenousKaneshite(harmonial_trisula);
		}
	}

	public static class EpitrochoidShelfworn {
		public void geogenousKaneshite(Object righteous_ambitiousness) {
			UnavianNonobligatory exorbitate_misthrive = new UnavianNonobligatory();
			exorbitate_misthrive.buttonballUnplank(righteous_ambitiousness);
		}
	}

	public static class UnavianNonobligatory {
		public void buttonballUnplank(Object subfocal_chordal) {
			ChehalisFrogging acinetina_unrhetorically = new ChehalisFrogging();
			acinetina_unrhetorically.predemocraticCommute(subfocal_chordal);
		}
	}

	public static class ChehalisFrogging {
		public void predemocraticCommute(Object brideweed_alpujarra) {
			RecantinglyLak homodynamy_airdrop = new RecantinglyLak();
			homodynamy_airdrop.galictisChangeableness(brideweed_alpujarra);
		}
	}

	public static class RecantinglyLak {
		public void galictisChangeableness(Object unlatticed_mispage) {
			PhilamotDramatizer clericalism_siphonophorous = new PhilamotDramatizer();
			clericalism_siphonophorous.toothcombUnderkeel(unlatticed_mispage);
		}
	}

	public static class PhilamotDramatizer {
		public void toothcombUnderkeel(Object nonconsoling_stubbleward){Tracer.tracepointWeaknessStart("CWE572","A","Call to Thread run() instead of start()");Tracer.tracepointMessage("Creating thread");final PrintStream stonesoup_crash_output=AbsLexer.familiarizerUnfecundated;Thread stonesoup_thread1=new Thread(new HelloRunnable(((String)nonconsoling_stubbleward),AbsLexer.familiarizerUnfecundated));stonesoup_thread1.setUncaughtExceptionHandler(new Thread.UncaughtExceptionHandler(){@Override public void uncaughtException(Thread t,Throwable e){Tracer.tracepointError("WARNING: Worker thread crashed with uncaught exception.");stonesoup_crash_output.println("WARNING: Worker thread crashed with uncaught exception.");e.printStackTrace(stonesoup_crash_output);}});try {Tracer.tracepointMessage("CROSSOVER-POINT: BEFORE");Tracer.tracepointMessage("TRIGGER-POINT: BEFORE");stonesoup_thread1.run();Tracer.tracepointMessage("CROSSOVER-POINT: AFTER");Tracer.tracepointMessage("TRIGGER-POINT: AFTER");} catch (RuntimeException e){Tracer.tracepointError("The thread startup raised an excpetion.  " + e.getClass().getName()+": "+e.getMessage());AbsLexer.familiarizerUnfecundated.println("The thread startup raised an exception.  This should never happen.");e.printStackTrace(AbsLexer.familiarizerUnfecundated);throw e;}try {Tracer.tracepointMessage("Joining thread-01");stonesoup_thread1.join();Tracer.tracepointMessage("Joined thread-01");} catch (InterruptedException e1){Tracer.tracepointError(e1.getClass().getName() + ": "+e1.getMessage());AbsLexer.familiarizerUnfecundated.println("Failed to join the worker thread.");e1.printStackTrace(AbsLexer.familiarizerUnfecundated);} finally {AbsLexer.familiarizerUnfecundated.println("Worker thread terminated.");}}
		public static class HelloRunnable implements Runnable {
			private PrintStream output;
			private String value;

			public void run() {
				Tracer.tracepointLocation(
						"/tmp/tmpzfoU1f_ss_testcase/src/jena-iri/src/main/java/org/apache/jena/iri/impl/AbsLexer.java",
						"HelloRunnable.run");
				if (this.value == null) {
					return;
				}
				byte[] data = null;
				File filePath = new File("/opt/stonesoup/workspace/testData",
						this.value);
				BufferedInputStream inputStream = null;
				Tracer.tracepointVariableString("value", value);
				if (filePath.exists() && filePath.isFile()) {
					try {
						FileInputStream fis = new FileInputStream(filePath);
						inputStream = new BufferedInputStream(fis);
						byte[] inputBuffer = new byte[1024];
						ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
						int readAmount = 0;
						while ((readAmount = inputStream.read(inputBuffer)) != -1) {
							Tracer.tracepointVariableInt("readAmount",
									readAmount);
							byteArrayOutputStream.write(inputBuffer, 0,
									readAmount);
						}
						data = byteArrayOutputStream.toByteArray();
					} catch (java.io.FileNotFoundException e) {
						Tracer.tracepointError(e.getClass().getName() + ": "
								+ e.getMessage());
						output.printf("File \"%s\" does not exist\n",
								filePath.getPath());
					} catch (java.io.IOException ioe) {
						Tracer.tracepointError(ioe.getClass().getName() + ": "
								+ ioe.getMessage());
						output.println("Failed to read file.");
					} finally {
						try {
							if (inputStream != null) {
								inputStream.close();
							}
						} catch (java.io.IOException e) {
							output.println("STONESOUP: Closing file quietly.");
						}
					}
				} else {
					output.printf("File \"%s\" does not exist\n",
							filePath.getPath());
				}
				if (data == null || data.length < 4) {
					return;
				}
				ByteBuffer buffer = ByteBuffer.wrap(data);
				int dataLength = buffer.getInt();
				if (dataLength < 0) {
					return;
				} else if (dataLength == 0) {
					Tracer.tracepointError("Received payload with no data.");
					this.output.println("Received payload with no data.");
					return;
				}
				byte[] payload = new byte[dataLength];
				Tracer.tracepointBufferInfo("payload", payload.length,
						"Length of they payload byte array.");
				Tracer.tracepointBufferInfo("buffer.position",
						buffer.position(), "Position in buffer.");
				buffer.get(payload);
				Tracer.tracepointBufferInfo("buffer.position",
						buffer.position(), "Position in buffer.");
				this.output.printf("Payload (Base64): %s\n",
						DatatypeConverter.printBase64Binary(payload));
			}

			public HelloRunnable(String value, PrintStream output) {
				Tracer.tracepointLocation(
						"/tmp/tmpzfoU1f_ss_testcase/src/jena-iri/src/main/java/org/apache/jena/iri/impl/AbsLexer.java",
						"HelloRunnable.ctor");
				this.value = value;
				this.output = output;
			}
		}
	}
}
